@@ -3,17 +3,17 @@ import os
 import pytest
 import requests
 from pydantic import BaseModel
+
 from tktl.core.clients.http_client import API, interpret_response
 from tktl.core.config import settings
 from tktl.core.exceptions.exceptions import APIClientException
-from tktl.core.loggers import CliLogger
 from tktl.core.managers.auth import AuthConfigManager
 
 
 def test_instantiate_api_client():
     key = os.environ["TEST_USER_API_KEY"]
     AuthConfigManager.set_api_key(key)
-    client = API(api_url=settings.DEPLOYMENT_API_URL, logger=CliLogger())
+    client = API(api_url=settings.DEPLOYMENT_API_URL)
     assert "X-Api-Key" in client.default_headers
     assert client.default_headers["X-Api-Key"] == key
     assert (
@@ -25,7 +25,7 @@ def test_instantiate_api_client():
 
 
 def test_request_failures():
-    client = API(api_url=settings.DEPLOYMENT_API_URL, logger=CliLogger())
+    client = API(api_url=settings.DEPLOYMENT_API_URL)
     response = client.post("non/existent/path")
     with pytest.raises(requests.exceptions.RequestException):
         response.raise_for_status()
@@ -48,7 +48,7 @@ def test_request_failures():
 
 
 def test_interpret_response():
-    client = API(api_url=settings.DEPLOYMENT_API_URL, logger=CliLogger())
+    client = API(api_url=settings.DEPLOYMENT_API_URL)
     response = client.post("non/existent/path")
     with pytest.raises(APIClientException) as e:
         interpret_response(response, model=BaseModel)
