@@ -9,8 +9,8 @@ def serializer_df_inputs():
     # from: pandas.tests.frame.conftest.float_frame_with_na
     df = pandas.DataFrame(tm.getSeriesData())
     # set some NAs
-    df.loc[5:10] = numpy.nan
-    df.loc[15:20, -2:] = numpy.nan
+    df.iloc[5:10] = numpy.nan
+    df.iloc[15:20, -2:] = numpy.nan
     return df
 
 
