@@ -2,8 +2,7 @@ import click
 import colorama
 from click._compat import get_text_stderr
 
-import tktl.cli.auth
-import tktl.cli.deployments
+import tktl.cli.login
 
 
 def show(self, file=None):
