@@ -2,10 +2,10 @@ import functools
 
 import click
 from click_didyoumean import DYMMixin
-from click_help_colors import HelpColorsGroup
+from click_help_colors import HelpColorsCommand, HelpColorsGroup
 from pydantic import UUID4
 
-from tktl.core.loggers import CliLogger
+from tktl.core.loggers import LOG
 
 OPTIONS_FILE_OPTION_NAME = "optionsFile"
 OPTIONS_FILE_PARAMETER_NAME = "options_file"
@@ -29,6 +29,10 @@ class ClickGroup(DYMMixin, HelpColorsGroup, AliasedGroup):
     pass
 
 
+class ClickCommand(DYMMixin, HelpColorsCommand):
+    pass
+
+
 def deprecated(msg):
     deprecated_invoke_notice = (
         msg
@@ -48,9 +52,6 @@ If you depend on functionality not listed there, please file an issue."""
     return decorator
 
 
-logger = CliLogger()
-
-
 _shared_options = [
     click.option("-f", "--full", help="Full (verbose) output", is_flag=True),
     click.option(
@@ -66,11 +67,33 @@ _shared_options = [
 ]
 
 
-def get_cmd_shared_options(func):
-    for option in reversed(_shared_options):
+_filter_deploy_shared_options = [
+    click.option("-c", "--commit", help="Commit hash"),
+    click.option("-b", "--branch", help="Branch name"),
+    click.option("-s", "--status", help="Status in which deployment is"),
+]
+
+
+_filter_repo_shared_options = [
+    click.option("-r", "--repo", help="Repository name"),
+    click.option("-o", "--owner", help="Owner of the repository"),
+]
+
+
+def shared_options_to_decorator(options, func):
+    for option in reversed(options):
         func = option(func)
     return func
 
 
-def to_uuid(_, x):
+get_cmd_shared_options = functools.partial(shared_options_to_decorator, _shared_options)
+filter_deploy_shared_options = functools.partial(
+    shared_options_to_decorator, _filter_deploy_shared_options
+)
+filter_repo_shared_options = functools.partial(
+    shared_options_to_decorator, _filter_repo_shared_options
+)
+
+
+def to_uuid(_, __, x):
     return UUID4(x) if x else None
