@@ -10,15 +10,19 @@ from tktl.core.schemas.repository import Endpoint
 class GetDeployments(BaseDeploymentApiCommand):
     def execute(
         self,
-        deployment_id: UUID4,
-        commit_sha: str,
+        repository_id: UUID4,
+        repository_name: str,
+        repository_owner: str,
+        git_hash: str,
         branch_name: str,
         status_name: str,
         return_all: bool = False,
     ):
         return self.client.get_deployments(
-            deployment_id=deployment_id,
-            commit_sha=commit_sha,
+            repository_id=repository_id,
+            repository_name=repository_name,
+            repository_owner=repository_owner,
+            git_hash=git_hash,
             branch_name=branch_name,
             status_name=status_name,
             return_all=return_all,
@@ -27,14 +31,9 @@ class GetDeployments(BaseDeploymentApiCommand):
 
 class GetRepositories(BaseDeploymentApiCommand):
     def execute(
-        self,
-        repository_id: UUID4,
-        repository_name: str,
-        repository_owner: str,
-        return_all: bool = False,
+        self, repository_name: str, repository_owner: str, return_all: bool = False,
     ):
         return self.client.get_repositories(
-            repository_id=repository_id,
             repository_name=repository_name,
             repository_owner=repository_owner,
             return_all=return_all,
@@ -43,10 +42,27 @@ class GetRepositories(BaseDeploymentApiCommand):
 
 class GetEndpoints(BaseDeploymentApiCommand):
     def execute(
-        self, endpoint_id: UUID4, endpoint_name: str, return_all: bool = False
+        self,
+        deployment_id: UUID4,
+        repository_name: str,
+        repository_owner: str,
+        git_hash: str,
+        branch_name: str,
+        status_name: str,
+        endpoint_name: str,
+        endpoint_kind: str,
+        return_all: bool = False,
     ) -> List[Endpoint]:
         return self.client.get_endpoints(
-            endpoint_id=endpoint_id, endpoint_name=endpoint_name, return_all=return_all
+            deployment_id=deployment_id,
+            repository_name=repository_name,
+            repository_owner=repository_owner,
+            git_hash=git_hash,
+            branch_name=branch_name,
+            status_name=status_name,
+            endpoint_name=endpoint_name,
+            endpoint_kind=endpoint_kind,
+            return_all=return_all,
         )
 
 
