@@ -4,7 +4,9 @@ import os
 from openapi_schema_pydantic import OpenAPI
 
 from tktl.core.clients import Client
-from tktl.core.clients.http_client import API
+from tktl.core.clients.http_client import API, interpret_response
+from tktl.core.config import settings
+from tktl.core.loggers import LOG, Logger
 from tktl.core.schemas.repository import _format_http_url
 from tktl.core.t import ServiceT
 
@@ -15,66 +17,50 @@ class RestClient(Client):
 
     TRANSPORT = ServiceT.REST
 
-    def __init__(self, api_key: str, repository_name: str, local: bool = False):
-        super().__init__(api_key=api_key, repository_name=repository_name)
-        self._location = None
-        self._endpoint = None
-        self._client = None
-        self.local = local
+    def __init__(
+        self,
+        api_key: str,
+        repository_name: str,
+        branch_name: str,
+        endpoint_name: str,
+        local: bool = False,
+        logger: Logger = LOG,
+        verbosity: int = 0,
+        health_check: bool = False,
+    ):
+        super().__init__(
+            api_key=api_key,
+            repository_name=repository_name,
+            branch_name=branch_name,
+            endpoint_name=endpoint_name,
+            local=local,
+            logger=logger,
+            verbosity=verbosity,
+        )
+        if not health_check:
+            self.authenticate()
 
     def predict(self, inputs):
         response = self.client.post(
-            url=f"model/{self.endpoint}", data=json.dumps(inputs)
+            url=f"model/{self.endpoint_name}", data=json.dumps(inputs)
         )
         return response.json()
 
-    def list_endpoints(self):
-        return {
-            e["endpoint"].name: _format_http_url(e["deployment"].public_docs_url)
-            for e in self.taktile_client.get_endpoints_for_repository(
-                repository=self.repository_name
-            )
-        }
+    @staticmethod
+    def format_url(url: str):
+        return _format_http_url(url, docs=False)
 
-    def __set_endpoint_and_location(self, endpoint_name: str):
-        self.endpoint = endpoint_name
-        if self.local:
-            self.location = self.local_endpoint
+    def authenticate(self, health_check: bool = False):
+        if health_check:
+            location = self.get_deployment_location()
         else:
-            self.location = self.list_endpoints()[endpoint_name]
-
-    def authenticate(self, endpoint_name: str):
-        self.__set_endpoint_and_location(endpoint_name)
-        client = API(api_url=self.location)
-        self.client = client
-
-    @property
-    def client(self) -> API:
-        return self._client
-
-    @client.setter
-    def client(self, client: API):
-        self._client = client
-
-    @property
-    def location(self):
-        return self._location
-
-    @location.setter
-    def location(self, value):
-        self._location = value
-
-    @property
-    def endpoint(self):
-        return self._endpoint
-
-    @endpoint.setter
-    def endpoint(self, value):
-        self._endpoint = value
+            location = self.get_endpoint_and_location()
+        client = API(api_url=location)
+        self.set_client_and_location(location=location, client=client)
 
     @property
     def local_endpoint(self):
-        return "http://0.0.0.0:8080"
+        return settings.LOCAL_REST_ENDPOINT
 
     def list_deployments(self):
         pass
@@ -83,7 +69,7 @@ class RestClient(Client):
         schema = self.client.get(url="openapi.json")
         openapi = OpenAPI.parse_obj(schema.json())
         request_reference, response_reference = get_endpoint_model_reference(
-            openapi, endpoint=self.endpoint
+            openapi, endpoint=self.endpoint_name
         )
         sample_input = openapi.components.schemas[request_reference].example
         if not sample_input:
@@ -93,6 +79,10 @@ class RestClient(Client):
             self.logger.warning("No sample output found for endpoint")
         return sample_input, sample_output
 
+    def health(self):
+        response = self.client.get(url=f"openapi.json")
+        return interpret_response(response, model=None, ping=True)
+
 
 def get_endpoint_model_reference(openapi: OpenAPI, endpoint: str):
     for k in openapi.paths.keys():
