@@ -14,7 +14,7 @@ log = logging.getLogger("root")
 
 class BaseConfigManager(object):
     """Base class for managing a configuration file.
-        Based on the amazing github.com/polyaxon/polyaxon config manager setup
+    Based on the amazing github.com/polyaxon/polyaxon config manager setup
     """
 
     TKTL_DIR: str = None
@@ -46,6 +46,7 @@ class BaseConfigManager(object):
         cfg_path = os.path.join(path, cls.SETTINGS.CONFIG_FILE_NAME)
         with open(cfg_path, "w") as cfg:
             json.dump(values, cfg, indent=2, sort_keys=True)
+            cfg.write("\n")
         return values
 
     @classmethod
@@ -57,10 +58,10 @@ class BaseConfigManager(object):
         if not os.path.exists(dir_path):
             try:
                 os.makedirs(dir_path)
-            except OSError:
+            except OSError as e:
                 # Except permission denied and potential race conditions
                 # in multi-threaded environments.
-                log.error("Could not create config directory `%s`", dir_path)
+                log.error(f"Could not create config directory {dir_path}: {repr(e)}")
 
     @classmethod
     def get_config_file_path(cls) -> str:
