@@ -1,4 +1,4 @@
-from typing import List, Union
+from typing import List, Optional, Union
 
 from pydantic import BaseModel
 
@@ -37,35 +37,23 @@ class TktlServiceConfigSchema(BaseModel):
     service_type: ServiceT
 
 
-class TktlAssetConfigSchema(BaseModel):
-    path: str
-    version: int
-
-
 class TktlYamlConfigSchema(BaseModel):
 
     """
-    default_branch_name: master
+    deployment_prefix?: master
     service:
 
       replicas: 2
       instance_type: gp.small
       service_type: rest
 
-    model:
-      path: assets/model.pkl
-      version: 1
-
-    data:
-      path: assets/data.pkl
-      version: 1
 
+    version: version
     """
 
-    default_branch_name: str
+    deployment_prefix: Optional[str]
     service: TktlServiceConfigSchema
-    model: TktlAssetConfigSchema
-    data: TktlAssetConfigSchema
+    version: str
 
 
 class TktlYamlConfigValidationError(BaseModel):
