@@ -2,10 +2,10 @@ import json
 from functools import wraps
 
 import requests
+from pydantic.types import UUID4
 
 from tktl.core.config import settings
-from tktl.core.exceptions import InvalidInputError
-from tktl.core.loggers import CliLogger
+from tktl.core.loggers import LOG
 from tktl.core.managers.auth import AuthConfigManager
 from tktl.core.strings import CLIStrings, HeaderStrings
 
@@ -16,8 +16,6 @@ UNAUTHORIZED_EXTENDED_INFO = (
     "the CLI client. For more information, please refer to the CLI client documentation."
 )
 
-logger = CliLogger()
-
 
 def is_error_or_missing_keys_print(res, *required_keys):
     if "error" in res:
@@ -50,10 +48,14 @@ def login(api_key=None):
     -------
 
     """
-
-    if not api_key:
-        raise InvalidInputError(CLIStrings.INVALID_INPUT + "api_key must be provided")
-
+    if api_key is None:
+        LOG.error("Authentication failed: no key provided")
+        return False
+    try:
+        UUID4(api_key)
+    except ValueError:
+        LOG.error("Authentication failed: Key format is invalid")
+        return False
     AuthConfigManager.set_api_key(api_key)
     return True
 
@@ -64,7 +66,7 @@ def set_api_key(api_key):
         f"{AuthConfigManager.get_tktl_config_path()}/"
         f"{AuthConfigManager.SETTINGS.CONFIG_FILE_NAME}"
     )
-    logger.log(f"Successfully added your API Key to {path} You're ready to go!")
+    LOG.log(f"Successfully added your API Key to {path} You're ready to go!")
     return True
 
 
@@ -77,7 +79,7 @@ def validate_key(suppress=False, api_key=None):
     if not api_key:
         api_key = AuthConfigManager.get_api_key()
     if not api_key:
-        logger.error(CLIStrings.AUTH_ERROR_MISSING_KEY)
+        LOG.error(CLIStrings.AUTH_ERROR_MISSING_KEY)
         return False
 
     r = requests.get(
@@ -87,11 +89,11 @@ def validate_key(suppress=False, api_key=None):
     try:
         r.raise_for_status()
     except requests.exceptions.RequestException as e:
-        logger.error(f'Request failed: {r.json()["detail"]}')
+        LOG.error(f'Request failed: {r.json()["detail"]}')
         return False
 
     if not suppress:
-        logger.log("Login successful!", color="green")
+        LOG.log("Login successful!", color="green")
     return True
 
 
